@@ -1,22 +1,8 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2008-2011  Intel Corporation
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2008-2011  Intel Corporation. All rights reserved.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifdef HAVE_CONFIG_H
@@ -199,7 +185,7 @@ static DBusMessage *set_cphs_mbdn(struct ofono_message_waiting *mw,
 
 	req->mw = mw;
 	req->mailbox = mailbox;
-	string_to_phone_number(number, &req->number);
+	__string_to_phone_number(number, &req->number);
 	req->cphs = TRUE;
 
 	sim_adn_build(efmbdn, req->mw->ef_cphs_mbdn_length,
@@ -298,7 +284,7 @@ static DBusMessage *set_mbdn(struct ofono_message_waiting *mw, int mailbox,
 
 	req->mw = mw;
 	req->mailbox = mailbox;
-	string_to_phone_number(number, &req->number);
+	__string_to_phone_number(number, &req->number);
 	req->cphs = FALSE;
 
 	sim_adn_build(efmbdn, req->mw->efmbdn_length, &req->number, NULL);
@@ -368,15 +354,19 @@ static DBusMessage *mw_set_property(DBusConnection *conn, DBusMessage *msg,
 	return __ofono_error_invalid_args(msg);
 }
 
-static GDBusMethodTable message_waiting_methods[] = {
-	{ "GetProperties",	"",	"a{sv}",	mw_get_properties	},
-	{ "SetProperty",	"sv",	"",		mw_set_property,
-							G_DBUS_METHOD_FLAG_ASYNC },
+static const GDBusMethodTable message_waiting_methods[] = {
+	{ GDBUS_METHOD("GetProperties",
+			NULL, GDBUS_ARGS({ "properties", "a{sv}" }),
+			mw_get_properties) },
+	{ GDBUS_ASYNC_METHOD("SetProperty",
+			GDBUS_ARGS({ "property", "s" }, { "value", "v" }),
+			NULL, mw_set_property) },
 	{ }
 };
 
-static GDBusSignalTable message_waiting_signals[] = {
-	{ "PropertyChanged",	"sv" },
+static const GDBusSignalTable message_waiting_signals[] = {
+	{ GDBUS_SIGNAL("PropertyChanged",
+			GDBUS_ARGS({ "name", "s" }, { "value", "v" })) },
 	{ }
 };
 
@@ -477,7 +467,7 @@ static void mw_mwis_read_cb(int ok, int total_length, int record,
 	status = data[0];
 	data++;
 
-	for (i = 0; i < 5 && i < record_length - 1; i++) {
+	for (i = 0; i < 5 && i < record_length - 1; i++, data++) {
 		info.indication = (status >> i) & 1;
 		info.message_count = info.indication ? data[0] : 0;
 
@@ -728,6 +718,7 @@ static void mw_set_indicator(struct ofono_message_waiting *mw, int profile,
 		efmwis[i + 1] = mw->messages[i].message_count;
 
 	/* Fill in indicator state bits in byte 0 */
+	efmwis[0] = 0;
 	for (i = 0; i < 5 && i < mw->efmwis_length - 1; i++)
 		if (mw->messages[i].indication)
 			efmwis[0] |= 1 << i;
@@ -748,8 +739,8 @@ try_cphs:
 	efmwis[0] = mw->messages[0].indication ? 0xa : 0x5;
 
 	if (mw->ef_cphs_mwis_length > 1)
-		efmwis[1] = mw->messages[1].indication ? 0xa : 0x5 |
-			mw->messages[3].indication ? 0xa0 : 0x50;
+		efmwis[1] = (mw->messages[1].indication ? 0xa : 0x5) |
+			(mw->messages[3].indication ? 0xa0 : 0x50);
 
 	if (ofono_sim_write(mw->sim_context, SIM_EF_CPHS_MWIS_FILEID,
 				mw_mwis_write_cb,
